pykoala.instruments package
===========================

Submodules
----------

pykoala.instruments.hector\_ifu module
--------------------------------------

.. automodule:: pykoala.instruments.hector_ifu
   :members:
   :undoc-members:
   :show-inheritance:

pykoala.instruments.koala\_ifu module
-------------------------------------

The Kilofibre Optical AAT Lenslet Array (`KOALA <https://aat.anu.edu.au/science/instruments/current/koala/overview>`_), is a wide-field, high efficiency, integral field unit used by the 
AAOmega spectrograph on the 3.9m AAT (`Anglo-Australian Telescope <https://aat.anu.edu.au/about-us/AAT>`_) at Siding Spring Observatory.

The current version of PyKOALA requires users to previously process the raw data with `2dfdr <https://aat.anu.edu.au/science/instruments/current/AAOmega/reduction>`_.

.. automodule:: pykoala.instruments.koala_ifu
   :members:
   :undoc-members:
   :show-inheritance:

pykoala.instruments.weave module
--------------------------------

.. automodule:: pykoala.instruments.weave
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pykoala.instruments
   :members:
   :undoc-members:
   :show-inheritance:
